@@ -7,7 +7,7 @@ use Exporter;
 our @ISA=qw(Exporter);
 our @EXPORT=qw(distance midpoint slope gradient);
 
-our $VERSION='1.0.0';
+our $VERSION='1.0.1';
 our $LIBRARY=__PACKAGE__;
 
 sub distance(x1,y1,x2,y2){return sqrt((x2-x1)**2+(y2-y1)**2)}
@@ -27,11 +27,11 @@ Math::CooGeo - Coordinate geometry library for Perl.
 
 =head1 VERSION
 
-Version 1.0.0
+Version 1.0.1
 
 =head1 DESCRIPTION
 
-Math::CooGeo is ...
+Math::CooGeo is coordinate geometry library for Perl.
 
 =head1 METHODS
 
@@ -139,6 +139,8 @@ Discord: DeBos#3292
 
 L<GitHub|https://github.com/DeBos99/Math-CooGeo/issues>
 
+=back
+
 =head1 AUTHOR
 
 Michał Wróblewski <debos@cpan.org>
